summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--checkers/classes.py26
-rw-r--r--checkers/similar.py2
-rw-r--r--checkers/utils.py2
-rw-r--r--lint.py2
-rw-r--r--reporters/html.py2
-rw-r--r--setup.py2
-rw-r--r--test/input/func_w0223.py4
7 files changed, 20 insertions, 20 deletions
diff --git a/checkers/similar.py b/checkers/similar.py
index 903c19e..0c5fe7b 100644
--- a/checkers/similar.py
+++ b/checkers/similar.py
@@ -251,7 +251,7 @@ class SimilarChecker(BaseChecker, Similar):
def set_option(self, opt_name, value, action=None, opt_dict=None):
"""method called to set an option (registered in the options list)
- overriden to report options setting to Similar
+ overridden to report options setting to Similar
"""
BaseChecker.set_option(self, opt_name, value, action, opt_dict)
if opt_name == 'min-similarity-lines':
diff --git a/checkers/utils.py b/checkers/utils.py
index 8c6612a..ba8bd41 100644
--- a/checkers/utils.py
+++ b/checkers/utils.py
@@ -169,7 +169,7 @@ def overrides_an_abstract_method(class_node, name):
return False
def overrides_a_method(class_node, name):
- """return True if <name> is a method overriden from an ancestor"""
+ """return True if <name> is a method overridden from an ancestor"""
for ancestor in class_node.ancestors():
if name in ancestor and isinstance(ancestor[name], astng.Function):
return True
diff --git a/lint.py b/lint.py
index abda05b..442dde0 100644
--- a/lint.py
+++ b/lint.py
@@ -301,7 +301,7 @@ This is used by the global evaluation report (R0004).'}),
reporter.linter = self
def set_option(self, opt_name, value, action=None, opt_dict=None):
- """overriden from configuration.OptionsProviderMixin to handle some
+ """overridden from configuration.OptionsProviderMixin to handle some
special options
"""
if opt_name in self._options_methods:
diff --git a/reporters/html.py b/reporters/html.py
index 5fd4350..d25cc2e 100644
--- a/reporters/html.py
+++ b/reporters/html.py
@@ -49,7 +49,7 @@ class HTMLReporter(BaseReporter):
def _display(self, layout):
"""launch layouts display
- overriden from BaseReporter to add insert the messages section
+ overridden from BaseReporter to add insert the messages section
(in add_message, message is not displayed, just collected so it
can be displayed in an html table)
"""
diff --git a/setup.py b/setup.py
index 39c4900..befbfcb 100644
--- a/setup.py
+++ b/setup.py
@@ -138,7 +138,7 @@ class MyInstallLib(install_lib.install_lib):
include_dirs variable if necessary
"""
def run(self):
- """overriden from install_lib class"""
+ """overridden from install_lib class"""
install_lib.install_lib.run(self)
# create Products.__init__.py if needed
if subpackage_of:
diff --git a/test/input/func_w0223.py b/test/input/func_w0223.py
index 3696862..e1e81bf 100644
--- a/test/input/func_w0223.py
+++ b/test/input/func_w0223.py
@@ -8,12 +8,12 @@ class Abstract:
"""abstract class
"""
def aaaa(self):
- """should be overriden in concrete class"""
+ """should be overridden in concrete class"""
raise NotImplementedError()
def bbbb(self):
- """should be overriden in concrete class"""
+ """should be overridden in concrete class"""
raise NotImplementedError()
def __init__(self):
diff --git a/checkers/classes.py b/checkers/classes.py
index c1da969..56bd48e 100644
--- a/checkers/classes.py
+++ b/checkers/classes.py
@@ -77,13 +77,13 @@ MSGS = {
class implementing this interface'),
'W0221': ('Arguments number differs from %s method',
'Used when a method has a different number of arguments than in \
the implemented interface or in an overriden method.'),
'W0222': ('Signature differs from %s method',
'Used when a method signature is different than in the \
- implemented interface or in an overriden method.'),
- 'W0223': ('Method %r is abstract in class %r but is not overriden',
+ implemented interface or in an overridden method.'),
+ 'W0223': ('Method %r is abstract in class %r but is not overridden',
'Used when an abstract method (ie raise NotImplementedError) is \
- not overriden in concrete class.'
+ not overridden in concrete class.'
),
'F0220': ('failed to resolve interfaces implemented by %s (%s)', # W0224
'Used when a PyLint as failed to find interfaces implemented by \
@@ -106,7 +106,7 @@ MSGS = {
class ClassChecker(BaseChecker):
"""checks for :
* methods without self as first argument
* overriden methods signature
* access only to existant members via self
* attributes not defined in the __init__ method
* supported interfaces implementation
@@ -209,10 +209,10 @@ instance attributes.'}
self._check_init(node)
return
# check signature if the method overrload an herited method
- for overriden in klass.local_attr_ancestors(node.name):
+ for overridden in klass.local_attr_ancestors(node.name):
# get astng for the searched method
try:
- meth_node = overriden[node.name]
+ meth_node = overridden[node.name]
except KeyError:
# we have found the method but it's not in the local
# dictionnary.
@@ -220,14 +220,14 @@ instance attributes.'}
continue
if not isinstance(meth_node, astng.Function):
continue
- self._check_signature(node, meth_node, 'overriden')
+ self._check_signature(node, meth_node, 'overridden')
break
# check if the method overload an attribute
try:
- overriden = klass.instance_attr(node.name)[0] # XXX
- while not isinstance(overriden, astng.Class):
- overriden = overriden.parent.frame()
- self.add_message('E0202', args=overriden.name, node=node)
+ overridden = klass.instance_attr(node.name)[0] # XXX
+ while not isinstance(overridden, astng.Class):
+ overridden = overridden.parent.frame()
+ self.add_message('E0202', args=overridden.name, node=node)
except astng.NotFoundError:
pass
@@ -235,7 +235,7 @@ instance attributes.'}
"""on method node, check if this method couldn't be a function
ignore class, static and abstract methods, initializer,
methods overriden from a parent class and any
kind of method defined in an interface for this warning
"""
if node.is_method():
@@ -77,13 +77,13 @@ MSGS = {
'W0221': ('Arguments number differs from %s method',
'Used when a method has a different number of arguments than in \
- the implemented interface or in an overriden method.'),
+ the implemented interface or in an overridden method.'),
'W0222': ('Signature differs from %s method',
'Used when a method signature is different than in the \
@@ -106,7 +106,7 @@ MSGS = {
"""checks for :
* methods without self as first argument
- * overriden methods signature
+ * overridden methods signature
* access only to existant members via self
* attributes not defined in the __init__ method
@@ -235,7 +235,7 @@ instance attributes.'}
"""on method node, check if this method couldn't be a function
ignore class, static and abstract methods, initializer,
- methods overriden from a parent class and any
+ methods overridden from a parent class and any
kind of method defined in an interface for this warning
"""